
graphANNIS Python Bindings
==========================

GraphANNIS (https://github.com/korpling/graphANNIS/) is a library for corpus linguistic queries 
and these are the Python bindings to **graphANNIS core library version 0.26.0**.

